Statistics
----------

The numbers generated by ``random`` are supposed to be distributed
uniformly. That means that each value in the range should be equally
likely. If we count the number of times each value appears, it should be
roughly the same for all values, provided that we generate a large
number of values.

In the next few sections, we will write programs that generate a
sequence of random numbers and check whether this property holds true.

.. fillintheblank:: statistics_1

    Random numbers are distributed __________.

    - :([Uu]niformly|UNIFORMLY): Correct!
      :.*: Incorrect!